==> gnome-system-monitor_46.0.orig.tar.xz: gnome-system-monitor-46.0/src/settings-keys.h <==
#ifndef _GSM_SETTINGS_KEYS_H_
#define _GSM_SETTINGS_KEYS_H_

#define GSM_GSETTINGS_SCHEMA                "org.gnome.gnome-system-monitor"
#define FONT_SETTINGS_SCHEMA                "org.gnome.desktop.interface"

#define FONT_SETTING_SCALING                "text-scaling-factor"

#define GSM_SETTINGS_CHILD_OPEN_FILES       "openfilestree"
#define GSM_SETTINGS_CHILD_DISKS            "disktreenew"
#define GSM_SETTINGS_CHILD_PROCESSES        "proctree"
#define GSM_SETTINGS_CHILD_MEMMAP           "memmapstree"

#define GSM_SETTING_WINDOW_WIDTH            "window-width"
#define GSM_SETTING_WINDOW_HEIGHT           "window-height"
#define GSM_SETTING_MAXIMIZED               "maximized"
#define GSM_SETTING_CURRENT_TAB             "current-tab"
#define GSM_SETTING_PROCESS_UPDATE_INTERVAL "update-interval"
#define GSM_SETTING_SHOW_WHOSE_PROCESSES    "show-whose-processes"
#define GSM_SETTING_SHOW_DEPENDENCIES       "show-dependencies"
#define GSM_SETTING_SHOW_KILL_DIALOG        "kill-dialog"
#define GSM_SETTING_SOLARIS_MODE            "solaris-mode"
#define GSM_SETTING_PROCESS_MEMORY_IN_IEC   "process-memory-in-iec"
#define GSM_SETTING_GRAPH_UPDATE_INTERVAL   "graph-update-interval"
#define GSM_SETTING_CPU_COLORS              "cpu-colors"
#define GSM_SETTING_MEM_COLOR               "mem-color"
#define GSM_SETTING_SWAP_COLOR              "swap-color"
#define GSM_SETTING_NET_IN_COLOR            "net-in-color"
#define GSM_SETTING_NET_OUT_COLOR           "net-out-color"
#define GSM_SETTING_DISK_READ_COLOR         "disk-read-color"
#define GSM_SETTING_DISK_WRITE_COLOR        "disk-write-color"
#define GSM_SETTING_LOGARITHMIC_SCALE       "logarithmic-scale"
#define GSM_SETTING_DRAW_STACKED            "cpu-stacked-area-chart"
#define GSM_SETTING_DRAW_SMOOTH             "cpu-smooth-graph"
#define GSM_SETTING_RESOURCES_MEMORY_IN_IEC "resources-memory-in-iec"
#define GSM_SETTING_NETWORK_IN_BITS         "network-in-bits"
#define GSM_SETTING_GRAPH_DATA_POINTS       "graph-data-points"
#define GSM_SETTING_NETWORK_TOTAL_IN_BITS   "network-total-in-bits"
#define GSM_SETTING_SHOW_CPU                "show-cpu"
#define GSM_SETTING_SHOW_MEM                "show-mem"
#define GSM_SETTING_SHOW_NETWORK            "show-network"
#define GSM_SETTING_DISKS_UPDATE_INTERVAL   "disks-interval"
#define GSM_SETTING_SHOW_ALL_FS             "show-all-fs"
#define GSM_SETTING_SMOOTH_REFRESH          "smooth-refresh"

#endif /* _GSM_SETTINGS_KEYS_H_ */

==> gnome-system-monitor_48.1.orig.tar.xz: gnome-system-monitor-48.1/src/settings-keys.h <==
#ifndef _GSM_SETTINGS_KEYS_H_
#define _GSM_SETTINGS_KEYS_H_

#define GSM_GSETTINGS_SCHEMA                "org.gnome.gnome-system-monitor"
#define FONT_SETTINGS_SCHEMA                "org.gnome.desktop.interface"

#define FONT_SETTING_SCALING                "text-scaling-factor"

#define GSM_SETTINGS_CHILD_OPEN_FILES       "openfilestree"
#define GSM_SETTINGS_CHILD_DISKS            "disksview"
#define GSM_SETTINGS_CHILD_PROCESSES        "proctree"
#define GSM_SETTINGS_CHILD_MEMMAP           "memmapstree"

#define GSM_SETTING_WINDOW_WIDTH            "window-width"
#define GSM_SETTING_WINDOW_HEIGHT           "window-height"
#define GSM_SETTING_MAXIMIZED               "maximized"
#define GSM_SETTING_CURRENT_TAB             "current-tab"
#define GSM_SETTING_RESOURCES_CPU_EXPANDED  "resources-cpu-expanded"
#define GSM_SETTING_RESOURCES_MEM_EXPANDED  "resources-mem-expanded"
#define GSM_SETTING_RESOURCES_NET_EXPANDED  "resources-net-expanded"
#define GSM_SETTING_RESOURCES_DISK_EXPANDED "resources-disk-expanded"
#define GSM_SETTING_PROCESS_UPDATE_INTERVAL "update-interval"
#define GSM_SETTING_SHOW_WHOSE_PROCESSES    "show-whose-processes"
#define GSM_SETTING_SHOW_DEPENDENCIES       "show-dependencies"
#define GSM_SETTING_SHOW_KILL_DIALOG        "kill-dialog"
#define GSM_SETTING_SOLARIS_MODE            "solaris-mode"
#define GSM_SETTING_PROCESS_MEMORY_IN_IEC   "process-memory-in-iec"
#define GSM_SETTING_GRAPH_UPDATE_INTERVAL   "graph-update-interval"
#define GSM_SETTING_CPU_COLORS              "cpu-colors"
#define GSM_SETTING_MEM_COLOR               "mem-color"
#define GSM_SETTING_SWAP_COLOR              "swap-color"
#define GSM_SETTING_NET_IN_COLOR            "net-in-color"
#define GSM_SETTING_NET_OUT_COLOR           "net-out-color"
#define GSM_SETTING_DISK_READ_COLOR         "disk-read-color"
#define GSM_SETTING_DISK_WRITE_COLOR        "disk-write-color"
#define GSM_SETTING_LOGARITHMIC_SCALE       "logarithmic-scale"
#define GSM_SETTING_DRAW_STACKED            "cpu-stacked-area-chart"
#define GSM_SETTING_DRAW_SMOOTH             "cpu-smooth-graph"
#define GSM_SETTING_RESOURCES_MEMORY_IN_IEC "resources-memory-in-iec"
#define GSM_SETTING_NETWORK_IN_BITS         "network-in-bits"
#define GSM_SETTING_GRAPH_DATA_POINTS       "graph-data-points"
#define GSM_SETTING_NETWORK_TOTAL_IN_BITS   "network-total-in-bits"
#define GSM_SETTING_SHOW_CPU                "show-cpu"
#define GSM_SETTING_SHOW_MEM                "show-mem"
#define GSM_SETTING_SHOW_NETWORK            "show-network"
#define GSM_SETTING_DISKS_UPDATE_INTERVAL   "disks-interval"
#define GSM_SETTING_SHOW_ALL_FS             "show-all-fs"
#define GSM_SETTING_SMOOTH_REFRESH          "smooth-refresh"

#endif /* _GSM_SETTINGS_KEYS_H_ */
